@@ -15,7 +15,6 @@
 struct process *
 open_program(char * filename) {
 	struct process * proc;
-	struct library_symbol * sym;
 	proc = malloc(sizeof(struct process));
 	if (!proc) {
 		perror("malloc");
@@ -23,39 +22,12 @@ open_program(char * filename) {
 	}
 	proc->filename = filename;
 	proc->pid = 0;
+	proc->breakpoints = NULL;
 	proc->breakpoints_enabled = -1;
 	proc->callstack_depth = 0;
 	proc->breakpoint_being_enabled = NULL;
+	breakpoints_init(proc);
 	proc->next = NULL;
-	if (opt_L && filename) {
-		proc->list_of_symbols = read_elf(filename);
-		if (opt_e) {
-			struct library_symbol ** tmp1 = &(proc->list_of_symbols);
-			while(*tmp1) {
-				struct opt_e_t * tmp2 = opt_e;
-				int keep = !opt_e_enable;
-
-				while(tmp2) {
-					if (!strcmp((*tmp1)->name, tmp2->name)) {
-						keep = opt_e_enable;
-					}
-					tmp2 = tmp2->next;
-				}
-				if (!keep) {
-					*tmp1 = (*tmp1)->next;
-				} else {
-					tmp1 = &((*tmp1)->next);
-				}
-			}
-		}
-	} else {
-		proc->list_of_symbols = NULL;
-	}
-	sym = proc->list_of_symbols;
-	while (sym) {
-		insert_breakpoint(proc, sym->enter_addr); /* proc->pid==0 delays enabling. */
-		sym = sym->next;
-	}
 
 	proc->next = list_of_processes;
 	list_of_processes = proc;
