@@ -18,20 +18,24 @@
 #define off_lr 56
 #define off_sp 52
 
-void * get_instruction_pointer(pid_t pid)
-{
+void *
+get_instruction_pointer(pid_t pid) {
 	return (void *)ptrace(PTRACE_PEEKUSER, pid, off_pc, 0);
 }
 
-void * get_stack_pointer(pid_t pid)
-{
+void
+set_instruction_pointer(pid_t pid, long addr) {
+	ptrace(PTRACE_POKEUSER, pid, off_pc, addr);
+}
+
+void *
+get_stack_pointer(pid_t pid) {
 	return (void *)ptrace(PTRACE_PEEKUSER, pid, off_sp, 0);
 }
 
 /* really, this is given the *stack_pointer expecting
  * a CISC architecture; in our case, we don't need that */
-void * get_return_addr(pid_t pid, void * stack_pointer)
-{
+void *
+get_return_addr(pid_t pid, void * stack_pointer) {
 	return (void *)ptrace(PTRACE_PEEKUSER, pid, off_lr, 0);
 }
-
