@@ -220,19 +220,19 @@
 	"madvise",                         /* 219 */
 	"getdents64",                      /* 220 */
 	"fcntl64",                         /* 221 */
-	"222",                             /* 222 */
+	"readahead",                       /* 222 */
 	"223",                             /* 223 */
-	"224",                             /* 224 */
-	"225",                             /* 225 */
-	"226",                             /* 226 */
-	"227",                             /* 227 */
-	"228",                             /* 228 */
-	"229",                             /* 229 */
-	"230",                             /* 230 */
-	"231",                             /* 231 */
-	"232",                             /* 232 */
-	"233",                             /* 233 */
-	"234",                             /* 234 */
-	"235",                             /* 235 */
+	"setxattr",                        /* 224 */
+	"lsetxattr",                       /* 225 */
+	"fsetxattr",                       /* 226 */
+	"getxattr",                        /* 227 */
+	"lgetxattr",                       /* 228 */
+	"fgetxattr",                       /* 229 */
+	"listxattr",                       /* 230 */
+	"llistxattr",                      /* 231 */
+	"flistxattr",                      /* 232 */
+	"removexattr",                     /* 233 */
+	"lremovexattr",                    /* 234 */
+	"fremovexattr",                    /* 235 */
 	"gettid",                          /* 236 */
 	"tkill",                           /* 237 */
